import { ESTree } from 'meriyah';
import { JSXContext } from './context';
export interface IdentifierBinding {
    type: 'Identifier';
    name: string;
    default?: any;
}
export interface PathBinding {
    [key: string]: Binding;
}
export interface ObjectBinding {
    type: 'Object';
    binds: PathBinding;
    rest: RestBinding | null;
    default?: any;
}
export interface ArrayBinding {
    type: 'Array';
    binds: (Binding | null)[];
    rest: RestBinding | null;
    default?: any;
}
export interface RestBinding {
    type: 'Rest';
    bind: Binding;
    default?: any;
}
export interface MemberBinding {
    type: 'Member';
    object: any;
    property: string;
    default?: any;
}
export declare type Binding = IdentifierBinding | ObjectBinding | ArrayBinding | RestBinding | MemberBinding;
export declare const evalBindingPattern: (bind: ESTree.BindingPattern | ESTree.AssignmentPattern | ESTree.Expression, context: JSXContext) => Binding;
export declare const evalIdentifierBinding: (bind: ESTree.Identifier, _: JSXContext) => IdentifierBinding;
export declare const evalObjectPattern: (bind: ESTree.ObjectPattern, context: JSXContext) => ObjectBinding;
export declare const evalArrayPattern: (bind: ESTree.ArrayPattern, context: JSXContext) => ArrayBinding;
export declare const evalAssignmentPattern: (bind: ESTree.AssignmentPattern, context: JSXContext) => Binding;
export declare const evalRestElement: (bind: ESTree.RestElement, context: JSXContext) => RestBinding;
export declare const evalMemberBinding: (bind: ESTree.MemberExpression, context: JSXContext) => MemberBinding;
export declare const setBinding: (bind: Binding, val: any, context: JSXContext, define?: "let" | "const" | "var" | undefined) => any;
//# sourceMappingURL=bind.d.ts.map