import { ESTree } from 'meriyah';
import { Binding, ComponentsBinding } from '../types/binding';
import { EvaluateOptions, AnyFunction } from './options';
declare class KeyGenerator {
    private readonly prefix;
    private readonly counter;
    constructor(prefix?: string);
    increment(): void;
    openingElement(): void;
    closingElement(): void;
    generate(): string;
}
declare type VariableKind = ESTree.VariableDeclaration['kind'];
declare class Variable {
    readonly kind: VariableKind;
    private init;
    private stored;
    constructor(kind: VariableKind);
    get value(): any;
    set value(val: any);
}
declare class Stack {
    readonly parent: Stack | undefined;
    readonly self: any;
    private variables;
    constructor(parent: Stack | undefined, self: any, init: Record<string, any>);
    get(name: string): Variable | undefined;
    define(kind: VariableKind, name: string): void;
    set(name: string, value: any): any;
}
export declare class JSXContext {
    readonly options: EvaluateOptions;
    readonly keyGenerator: KeyGenerator;
    readonly binding: Binding;
    readonly components: ComponentsBinding;
    readonly allowedFunctions: AnyFunction[];
    readonly deniedFunctions: AnyFunction[];
    readonly exports: Record<string, any>;
    stack: Stack;
    constructor(options: EvaluateOptions);
    get stackSize(): number;
    pushStack(self: any): void;
    popStack(): void;
    defineVariable(kind: VariableKind, name: string): void;
    setVariable(name: string, value: any): void;
    resolveThis(): any;
    resolveIdentifier(name: string): Variable | undefined;
    resolveComponent(name: string): any;
    export(name: string, value: any): void;
    private _label;
    get label(): string | undefined;
    set label(l: string | undefined);
    isAllowedFunction(func: AnyFunction): boolean;
    private isAllowedFunc;
    private isDeniedFunc;
    get hasAllowedFunctions(): boolean;
}
export {};
//# sourceMappingURL=context.d.ts.map